# mypy-boto3-discovery

[![PyPI - mypy-boto3-discovery](https://img.shields.io/pypi/v/mypy-boto3-discovery.svg?color=blue)](https://pypi.org/project/mypy-boto3-discovery)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-discovery.svg?color=blue)](https://pypi.org/project/mypy-boto3-discovery)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-discovery](#mypy-boto3-discovery)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)


Type annotations for
[boto3.ApplicationDiscoveryService 1.13.24](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/discovery.html#ApplicationDiscoveryService) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-discovery](#mypy-boto3-discovery)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ApplicationDiscoveryService` service.

```bash
python -m pip install boto3-stubs[discovery]

# update installed packages index for automated type discovery
python -m mypy_boto3
```

Use `boto3` with `mypy_boto3_discovery` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_discovery import ApplicationDiscoveryServiceClient

# Now mypy can check if your code is valid.
client: ApplicationDiscoveryServiceClient = boto3.client("discovery")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ApplicationDiscoveryServiceClient = session.client("discovery")



# Annotated paginators are included as well

import mypy_boto3_discovery.paginator as discovery_paginators

describe_agents_paginator: discovery_paginators.DescribeAgentsPaginator = client.get_paginator("describe_agents")
describe_continuous_exports_paginator: discovery_paginators.DescribeContinuousExportsPaginator = client.get_paginator("describe_continuous_exports")
describe_export_configurations_paginator: discovery_paginators.DescribeExportConfigurationsPaginator = client.get_paginator("describe_export_configurations")
describe_export_tasks_paginator: discovery_paginators.DescribeExportTasksPaginator = client.get_paginator("describe_export_tasks")
describe_tags_paginator: discovery_paginators.DescribeTagsPaginator = client.get_paginator("describe_tags")
list_configurations_paginator: discovery_paginators.ListConfigurationsPaginator = client.get_paginator("list_configurations")
```

## Automated type discovery

`mypy_boto3` package can generate index for `mypy_boto3_discovery` and other installed services.

```bash
# Run this command when you add or remove service packages
python -m mypy_boto3
```

Generated index provides overloads for `boto3.client` and `boto3.service`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully
- `VSCode` does not currently support function overloads

Also, generated index allows you to import types from `mypy_boto3`:

```python
# you can replace imports
import mypy_boto3_discovery as discovery
from mypy_boto3_discovery import ApplicationDiscoveryServiceClient

# with these
from mypy_boto3 import discovery
from mypy_boto3.discovery import ApplicationDiscoveryServiceClient
```